import logging
import re

from werkzeug.utils import ArgumentValidationError
from api.utils.errors import ValidationError

def validate(data):
    """ Function for validating storable data """
    errors = []

    # "It's not pretty, but it works."
    try:
        validate_lat(data['lat'])
    except ValidationError as e:
        errors.append(e.message)
    try:
        validate_lng(data['lng'])
    except ValidationError as e:
        errors.append(e.message)
    try:
        validate_name(data['name'])
    except ValidationError as e:
        errors.append(e.message)
    try:
        validate_person(data['person'])
    except ValidationError as e:
        errors.append(e.message)
    try:
        validate_keeper(data['keeper'])
    except ValidationError as e:
        errors.append(e.message)
    try:
        validate_email(data['email'])
    except ValidationError as e:
        errors.append(e.message)

    # Combines all the error messages in a single string so the end-user
    # can be notified of what went wrong.
    if len(errors) > 0:
        raise ValidationError(", ".join(errors))
    
    return True


def validate_lat(lat: float):
    if not -91 < float(lat) < 91:
        raise ValidationError.from_arguments(lat, "lat")

def validate_lng(lng: float):
    if not -181 < float(lng) < 181:
        raise ValidationError.from_arguments(lng, "lng")

def validate_name(name: str):
    if name.isspace() or len(name.strip()) < 3:
        raise ValidationError.from_arguments(name, "name")

def validate_person(person: str):
    if person.isspace():
        raise ValidationError.from_arguments(person, "person")

def validate_keeper(keeper: str):
    if keeper.isspace():
        raise ValidationError.from_arguments(keeper, "keeper")

def validate_email(email: str):
    if not re.match(r".+@+.", email):
        raise ValidationError.from_arguments(email, "email")

