# Weekly report: Week 4

## Tasks

### Administrative

- Four user stories were updated and three created according to the instructions.
- Group meeting with mentor was held on Monday 8.2.
- Time estimation report was created.


### DevOps

- *Work on implementing customer requirements.*
- *Add Localization support (see: docs/adding-localization.md).*
    - Base for localization added.
    - Localization works for all Python and HTML items
    - Localization support added for English and Finnish
- *Implement admin interface.*
    - Added OAuth2/OpenId authentication using Google OpenId client
    - Added a decorator that enforces role based access control to decorated routes
    - Created admin page that allows editing and deleting suggested beehives
    - **NOTE!!!**
        - The implementation uses flask sessions to store user information, which will cause
        erratic behavior if App Engine is running multiple instances of the application.
        - A better solution would be to use Google Memorystore (Redis) to cache sessions, but
        this would amount to too much work at this point.
- *Write bug and security issue reporting guide (see: GitLab: Description Templates).*
    - Bug and security issue reporting template was created. Template can be found in `.gitlab/issue_templates/Bug.md`.
- *Describe how to report issues in README.md.*
    - Issue reporting instructions added to README.md.
- *Bughunt! You will be assigned to evaluate two other teams’ implementation, and to identify security and bug issues within their solution (peer review).*
- *Reminder: Repository needs to be public.*
- *Bonus: Collect interesting metrics.*


## Vulnerability assessment

### Injection
All requests are filtered for injections and missing parameters. The main database is Google Cloud Datastore, which offers very little attack surface for injection type attacks.

### Broken authentication
The application uses Google's OAuth2/OpenId server to identify users on login. Authentication is fully handled server-side, and logged in users are identified using session cookies. Sessions are handled automatically by flask, including expiring old sessions, and the session cookies are encrypted using a randomized secret key.

Sensitive API endpoints only accept PUT and DELETE requests from authorized users. At this point though, all authenticated users are given the role 'admin', which allows accessing these endpoints. Only a manually configured group of users are allowed to authenticate. Google OAuth2 prevents other users from authenticating.

### Sensitive data exposure
All sensitive data is stored in environment variables in the ci/cd pipeline. OAuth2 client id and secret are stored inside the project's datastore.

### Security misconfiguration
The Google Cloud service account was configured to have only the roles necessary to build and deploy the application. The Kubernetes cluster can only be accessed via the GitLab CI or the owner of the GCloud project. Google credentials are not used in testing environments. 

### Cross-Site Scripting (XSS)
The application was vulnerable to XSS attacks due to two separate bugs that were found in an internal auditing session. The vulnerability was fixed shortly after and further testing has not uncovered any more vulnerabilities that would allow cross-site scripting.

### Using components with known vulnerabilities
Based on information from the snyk.io vulnerability database, no such components are in use. The application uses *authlib* for OAuth2, which seems to be the most actively maintained authentication library for flask.

### Insufficient logging & monitoring
Logging and monitoring for the Kubernetes cluster and App Engine are provided by the Google Cloud platform. Application logs and monitoring data are streamed to Google Cloud, but automatic alerts have not been set up yet.




