/**
 * Fetches previously submitted hive locations from the server,
 * returns an array of locations in the format:
 * {
 *   name,
 *   key,
 *   lat,
 *   lng
 * }
 *
 */
async function loadHiveLocations() {
  const response = await fetch('/api/hives');
  if (response.ok) {
    const responseJson = await response.json();
    console.log('Fetching hives ok');
    return responseJson;
  }

  console.log('Fetching hives not ok');
  return Promise.reject(response);
}

/**
 * Posts the submitted data to the server,
 * returns a promise containing the response json in the format:
 * {
 *   name,
 *   id,
 *   timestamp,
 *   key,
 *   lat,
 *   lng,
 *   person,
 *   keeper,
 *   email
 * }
 * @param {Object} data
 */
async function saveLocation(data) {
  const response = await fetch('/api/hives', {
    method: 'POST',
    headers: {
      'Content-Type': 'application/json',
      'x-csrf-token': csrfToken
    },
    body: JSON.stringify(data),
  });
  if (response.ok) {
    console.log('Posting new hive ok');
    const responseJson = await response.json();
    return responseJson;
  }

  console.log('Posting new hive not ok');
  return Promise.reject(response);
}

/**
 * Creates a delete request to the server
 * @param {Object} data
 */
async function deleteLocation(data) {
  const response = await fetch('/api/hives', {
    method: 'DELETE',
    headers: {
      'Content-Type': 'application/json',
      'x-csrf-token': csrfToken
    },
    body: JSON.stringify(data),
  });
  if (response.ok) {
    console.log('Deleting the hive ok');
    const responseJson = await response.json();
    return responseJson;
  }

  console.log('Deleting the hive not ok');
  return Promise.reject(response);
}

/**
 * Creates a put request to update the entity
 * {
 *   name,
 *   id,
 *   timestamp,
 *   key,
 *   lat,
 *   lng,
 *   person,
 *   keeper,
 *   email
 * }
 * @param {Object} data
 */
async function editLocation(data) {
  const response = await fetch('/api/hives', {
    method: 'PUT',
    headers: {
      'Content-Type': 'application/json',
      'x-csrf-token': csrfToken
    },
    body: JSON.stringify(data),
  });
  if (response.ok) {
    console.log('Editing hive ok');
    const responseJson = await response.json();
    return responseJson;
  }

  console.log('Editing hive not ok');
  return Promise.reject(response);
}

export {loadHiveLocations, saveLocation, deleteLocation, editLocation};
