import os
import sys
import json
import tracemalloc

topdir = os.path.join(os.path.dirname(__file__), "..")
sys.path.append(topdir)

tracemalloc.start()

ROOT_PATH = "/"
HIVES_PATH = "/api/hives"

#Test for response 200 from "/"
def test_get_index(client):
    with client:
        response = client.get(ROOT_PATH)
        assert response.status_code ==  200
        assert response.content_type ==  "text/html; charset=utf-8"


#Test for status in "/api/hives"
def test_get_locations_status(client):
    with client:
        response = client.get(HIVES_PATH)
        assert response.status_code ==  200
        assert response.content_type ==  "application/json"


def test_post_valid_location_status(client):
    body = {
        "name": "TestHive",
        "lat": 63.12123123,
        "lng": 121.32131231,
        "person": "Tester",
        "keeper": "TestKeeper",
        "email": "testkeeper@test.com"
    }
    
    with client:
        post_response = client.post(HIVES_PATH, json=body)
        assert post_response.status_code == 200
        get_response = client.get(HIVES_PATH)
        assert get_response.status_code ==  200
        assert get_response.content_type ==  "application/json"
        data = json.loads(get_response.data)
        latest = data[-1]
        assert latest['name'] == body['name']
        assert latest['id'] != None
        assert latest['id'] != -1
        assert latest['lat'] == body['lat']
        assert latest['lng'] == body['lng']


def test_post_invalid_location_status(client):
    body = {
        "name": "TestHive",
        "lat": 163.12123123,
        "lng": 121.32131231,
        "person": "Tester",
        "keeper": "TestKeeper",
        "email": "testkeeper@test.com"
    }
    
    with client:
        response = client.post(HIVES_PATH, json=body)
        assert response.status_code == 400
